@@ -28,6 +28,11 @@ MINIMUM_FIRMWARE = {
         "IPC_515BSD6": "v3.0.0.1107_22070508",
         "IPC_515SD6": "v3.0.0.1107_22070508",
     },
+    "RLC-410": {
+        "IPC-515B16M5M": "V3.0.0.136_20121100",
+        "IPC_51316M": "V3.0.0.136_20121100",
+        "IPC_51516M5M": "V3.0.0.136_20121100",
+    },
     "RLC-410W": {
         "IPC_30K128M4MP": "v3.1.0.739_22042505",
         "IPC_51516M5M": "v3.0.0.136_20121102",
@@ -38,6 +43,9 @@ MINIMUM_FIRMWARE = {
         "IPC_51516M5M": "v3.0.0.136_20121101",
         "IPC_515B16M5M": "v3.0.0.136_20121101",
     },
+    "RLC-510A": {
+        "IPC_523128M5MP": "v3.1.0.951_22041567",
+    },
     "RLC-511": {
         "IPC_51516M5M": "v3.0.0.142_20121803",
     },
@@ -63,12 +71,36 @@ MINIMUM_FIRMWARE = {
     "RLC-811A": {
         "IPC_523128M8MP": "v3.1.0.989_22051908",
     },
+    "RLC-812A": {
+        "IPC_523B188MP": "v3.1.0.920_22040613",
+    },
     "RLC-820A": {
         "IPC_523128M8MP": "v3.1.0.956_22041501",
     },
+    "RLC-822A": {
+        "IPC_523128M8MP": "v3.1.0.989_22081907",
+    },
     "RLC-823A": {
         "IPC_523128M8MP": "v3.1.0.989_22051911_v1.0.0.30",
     },
+    "Reolink TrackMix PoE": {
+        "IPC_529SD78MP": "v3.0.0.1817_23022700",
+    },
+    "Reolink TrackMix WiFi": {
+        "IPC_529SD78MP": "v3.0.0.1817_23022701",
+    },
+    "Reolink Duo PoE": {
+        "IPC_528B174MP": "v3.0.0.1388_22100600",
+    },
+    "Reolink Duo WiFi": {
+        "IPC_528B174MP": "v3.0.0.1388_22100601",
+    },
+    "Reolink Duo 2 POE": {
+        "IPC_529B17B8MP": "v3.0.0.1337_22091900",
+    },
+    "Reolink Duo 2 WiFi": {
+        "IPC_529B17B8MP": "v3.0.0.1337_22091901",
+    },
 }
 
 
